@@ -42,8 +42,6 @@ def get_event_description(item: dict) -> str:
         "default":
             "Unknown event"
     }
-    if item["type"] == "CreateEvent":
-        print(item)
     return event_types[item["type"]]
 
 async def fetch_user_name(user_name: str) -> dict:
